# The PIL.ImageEnhance Module

Brightness(image) (class) [#]

  Brightness enhancement object.

  For more information about this class, see The Brightness Class.

Color(image) (class) [#]

  Color enhancement object.

  For more information about this class, see The Color Class.

Contrast(image) (class) [#]

  Contrast enhancement object.

  For more information about this class, see The Contrast Class.

Sharpness(image) (class) [#]

  Sharpness enhancement object.

  For more information about this class, see The Sharpness Class.

## The Brightness Class

Brightness(image) (class) [#]

  Brightness enhancement object.

  This class can be used to control the brighntess of an image. An enhancement factor of 0.0 gives a black image, factor 1.0 gives the original image.

## The Color Class

Color(image) (class) [#]

  Color enhancement object.

  This class can be used to adjust the colour balance of an image, in a manner similar to the controls on a colour TV set. An enhancement factor of 0.0 gives a black and white image, a factor of 1.0 gives the original image.

## The Contrast Class

Contrast(image) (class) [#]

  Contrast enhancement object.

  This class can be used to control the contrast of an image, similar to the contrast control on a TV set. An enhancement factor of 0.0 gives an solid grey image, factor 1.0 gives the original image.

## The Sharpness Class

Sharpness(image) (class) [#]

  Sharpness enhancement object.

  This class can be used to adjust the sharpness of an image. The enhancement factor 0.0 gives a blurred image, 1.0 gives the original image, and a factor of 2.0 gives a sharpened image.